@@ -35,7 +35,7 @@
 #define EXP 3
 #define SEC 4
 
-GtkWidget *gnomecard_window;
+GnomeApp *gnomecard_window;
 
 GtkCList *gnomecard_list=NULL;
 GtkWidget *cardlist_scrollwin=NULL; /* scrollwin for cardlist */
@@ -339,7 +339,7 @@ void gnomecard_last_card(GtkWidget *widget, gpointer data)
 void gnomecard_quit(GtkWidget *widget, gpointer data)
 {
 	if (gnomecard_destroy_cards()) {
-		gtk_widget_destroy(gnomecard_window);
+		gtk_widget_destroy(GTK_WIDGET (gnomecard_window));
 		gtk_main_quit();
 	}
 }
@@ -347,7 +347,7 @@ void gnomecard_quit(GtkWidget *widget, gpointer data)
 gint gnomecard_delete(GtkWidget *w, GdkEvent *e, gpointer data)
 {
 	if (gnomecard_destroy_cards()) {
-		gtk_widget_destroy(gnomecard_window);
+		gtk_widget_destroy(GTK_WIDGET (gnomecard_window));
 		gtk_main_quit();
 	}
 	  
@@ -376,42 +376,26 @@ void gnomecard_spawn_new(GtkWidget *widget, gpointer data)
 }
 
 GnomeUIInfo filemenu[] = {
-	{GNOME_APP_UI_ITEM, N_("New Gnomecard"), N_("Spawn a new Card Manager."), 
-		gnomecard_spawn_new, NULL, NULL,
-	GNOME_APP_PIXMAP_STOCK, GNOME_STOCK_MENU_BOOK_OPEN, 0, 0, NULL},
 
-	{GNOME_APP_UI_SEPARATOR},
-	
-	{GNOME_APP_UI_ITEM, N_("New"), N_("Create new Card File."), 
-		gnomecard_destroy_cards, NULL, NULL,
-	GNOME_APP_PIXMAP_STOCK, GNOME_STOCK_MENU_NEW, 0, 0, NULL},
+	GNOMEUIINFO_MENU_NEW_ITEM(N_("New"), N_("Create a new card file"),
+				  gnomecard_destroy_cards, NULL),
 
-	{GNOME_APP_UI_ITEM, N_("Open..."), N_("Open a Card File."), 
-		gnomecard_open, NULL, NULL,
-	GNOME_APP_PIXMAP_STOCK, GNOME_STOCK_MENU_OPEN, 0, 0, NULL},
+	GNOMEUIINFO_MENU_OPEN_ITEM(gnomecard_open, NULL),
 
-	{GNOME_APP_UI_ITEM, N_("Append..."), N_("Add the contents of another Card File."),
-		gnomecard_append, NULL, NULL,
-	GNOME_APP_PIXMAP_STOCK, GNOME_STOCK_MENU_OPEN, 0, 0, NULL},
+	GNOMEUIINFO_MENU_SAVE_ITEM(gnomecard_save, NULL),
 
-	{GNOME_APP_UI_ITEM, N_("Save"), N_("Save current changes."), 
-		gnomecard_save, NULL, NULL,
-	GNOME_APP_PIXMAP_STOCK, GNOME_STOCK_MENU_SAVE, 0, 0, NULL},
+	GNOMEUIINFO_MENU_SAVE_AS_ITEM(gnomecard_save_as, NULL),
 
-	{GNOME_APP_UI_ITEM, N_("Save as..."), N_("Save current changes, choosing file name."), 
-		gnomecard_save_as, NULL, NULL,
-	GNOME_APP_PIXMAP_STOCK, GNOME_STOCK_MENU_SAVE_AS, 0, 0, NULL},
+	{GNOME_APP_UI_ITEM, N_("_Merge with..."),
+	 N_("Add the contents of another Card File."),
+	 gnomecard_append, NULL, NULL,
+	 GNOME_APP_PIXMAP_STOCK, GNOME_STOCK_MENU_OPEN, 0, 0, NULL},
 
-	{GNOME_APP_UI_SEPARATOR},
-	
-	{GNOME_APP_UI_ITEM, N_("Properties..."), N_("Appereance, customizations..."), gnomecard_setup, NULL, NULL,
-	GNOME_APP_PIXMAP_STOCK, GNOME_STOCK_MENU_PROP, 0, 0, NULL},
+	GNOMEUIINFO_SEPARATOR,
 
-	{GNOME_APP_UI_ITEM, N_("Exit"), N_("Close the program."), 
-		gnomecard_quit, NULL, NULL,
-	GNOME_APP_PIXMAP_STOCK, GNOME_STOCK_MENU_EXIT, 0, 0, NULL},
+	GNOMEUIINFO_MENU_EXIT_ITEM(gnomecard_quit, NULL),
 
-	{GNOME_APP_UI_ENDOFINFO}
+	GNOMEUIINFO_END
 };
 
 GnomeUIInfo gomenu[] = {
@@ -529,20 +513,25 @@ GnomeUIInfo viewmenu[] = {
 	{GNOME_APP_UI_ENDOFINFO}
 };
 
-GnomeUIInfo helpmenu[] = {
-	{GNOME_APP_UI_ITEM, N_("About..."), N_("Version, credits, etc."), 
-		gnomecard_about, NULL, NULL,
-	GNOME_APP_PIXMAP_STOCK, GNOME_STOCK_MENU_ABOUT, 0, 0, NULL},
+GnomeUIInfo settingsmenu[] = {
+        GNOMEUIINFO_MENU_PREFERENCES_ITEM(gnomecard_setup, NULL),
+	GNOMEUIINFO_END
+};
 
-	{GNOME_APP_UI_ENDOFINFO}
+GnomeUIInfo helpmenu[] = {
+        GNOMEUIINFO_HELP("gnomecard"),
+	GNOMEUIINFO_MENU_ABOUT_ITEM(gnomecard_about, NULL),
+	GNOMEUIINFO_END
 };
 
 GnomeUIInfo mainmenu[] = {
-	{GNOME_APP_UI_SUBTREE, N_("File"), NULL, filemenu, NULL, NULL,
-	GNOME_APP_PIXMAP_NONE, NULL, 0, 0, NULL},
+        GNOMEUIINFO_MENU_FILE_TREE(filemenu),
 
-	{GNOME_APP_UI_SUBTREE, N_("Edit"), NULL, editmenu, NULL, NULL,
-	GNOME_APP_PIXMAP_NONE, NULL, 0, 0, NULL},
+	GNOMEUIINFO_MENU_EDIT_TREE(editmenu),
+
+	GNOMEUIINFO_MENU_SETTINGS_TREE(settingsmenu),
+
+	GNOMEUIINFO_MENU_HELP_TREE(helpmenu),
 
 /*	{GNOME_APP_UI_SUBTREE, N_("Add"), NULL, addmenu, NULL, NULL,
 	GNOME_APP_PIXMAP_NONE, NULL, 0, 0, NULL},
@@ -550,10 +539,7 @@ GnomeUIInfo mainmenu[] = {
 /*	{GNOME_APP_UI_SUBTREE, N_("View"), NULL, viewmenu, NULL, NULL,
 	GNOME_APP_PIXMAP_NONE, NULL, 0, 0, NULL},*/
 
-	{GNOME_APP_UI_SUBTREE, N_("Help"), NULL, helpmenu, NULL, NULL,
-	GNOME_APP_PIXMAP_NONE, NULL, 0, 0, NULL},
-
-	{GNOME_APP_UI_ENDOFINFO}
+	GNOMEUIINFO_END
 };
 
 GnomeUIInfo toolbar[] = {
@@ -619,6 +605,7 @@ void gnomecard_sort_by_fname(GtkWidget *w, gpointer data)
 
 void gnomecard_init(void)
 {
+        GnomeAppBar *appbar;
 	GtkWidget *canvas, *align, *hbox, *hbox1, *hbox2;
 	GtkWidget *table, *w;
 	gint ncol, i;
@@ -631,21 +618,31 @@ void gnomecard_init(void)
 	gnomecard_init_stock();
 	gnomecard_init_pixes();
 	
-	gnomecard_window = gnome_app_new("GnomeCard", "GnomeCard");
+	gnomecard_window = GNOME_APP(gnome_app_new("GnomeCard", "GnomeCard"));
+
+	appbar = GNOME_APPBAR(gnome_appbar_new(TRUE, TRUE,
+					       GNOME_PREFERENCES_USER));
+	gnome_app_set_statusbar(GNOME_APP(gnomecard_window),
+				GTK_WIDGET(appbar));
+
+#if 0
 	gtk_window_set_wmclass(GTK_WINDOW(gnomecard_window), "GnomeCard",
 			       "GnomeCard");
 	gtk_window_set_policy(GTK_WINDOW(gnomecard_window), TRUE, TRUE, TRUE);
+#endif
 			      
-	gtk_widget_show(gnomecard_window);
 	gtk_signal_connect(GTK_OBJECT(gnomecard_window), "delete_event",
 			   GTK_SIGNAL_FUNC(gnomecard_delete), NULL);
 	
 	hbox = gtk_hbox_new(FALSE, 0);
-	gnome_app_set_contents(GNOME_APP(gnomecard_window), hbox);
 
 	gnome_app_create_menus(GNOME_APP(gnomecard_window), mainmenu);
+
+	gnome_app_install_menu_hints(GNOME_APP(gnomecard_window), mainmenu);
 	gnome_app_create_toolbar(GNOME_APP(gnomecard_window), toolbar);
 
+	gnome_app_set_contents(GNOME_APP(gnomecard_window), hbox);
+
 	cardlist_scrollwin = gtk_scrolled_window_new(NULL, NULL);
 	gtk_scrolled_window_set_policy(GTK_SCROLLED_WINDOW(cardlist_scrollwin),
 				   GTK_POLICY_AUTOMATIC, GTK_POLICY_AUTOMATIC);
@@ -746,6 +743,9 @@ void gnomecard_init(void)
 		gnomecard_open_file(gnomecard_fname);
 	else
 		gnomecard_set_curr(NULL);
+
+	gtk_widget_show(GTK_WIDGET (gnomecard_window));
+
 }
 
 int main (int argc, char *argv[])
